@@ -80,7 +80,20 @@ class Raster(object):
         self.transform = transform
         self.crs_string = crs_string
         self.name = name
-        self.dtype = gdal.GDT_Float32
+
+        if type(dtype) == str:
+            try:
+                self.dtype = GDAL_FIELD_DEF[dtype]
+            except Exception in (TypeError, ValueError, KeyError):
+                try:
+                    self.dtype = int(dtype)
+                except Exception in (TypeError, ValueError, KeyError):
+                    self.dtype = GDAL_FIELD_DEF['float']
+        elif type(dtype) in (int, float):
+            self.dtype = int(dtype)
+        else:
+            self.dtype = gdal.GDT_Float32
+
         self.metadict = metadict
         self.nodatavalue = None
         self.tile_grid = list()
@@ -390,10 +403,11 @@ class Raster(object):
                 except RuntimeError as e:
                     read_success = False
                     Opt.cprint(e)
-                    Opt.cprint('Retrying failed read... attempt {}'.format(i_try + 1))
+                    Opt.cprint('Retrying failed read... attempt {}'.format(str(i_try + 1)))
                     time.sleep(random.random() + 1.0)
 
             if not read_success:
+                Opt.cprint('Retrying failed with {} attempts...using no-data value'.format(str(n_tries)))
                 array3d[i, :, :] = self.nodatavalue
 
         if (self.shape[0] == 1) and (len(array3d.shape) > 2):
@@ -767,10 +781,8 @@ class Raster(object):
         if type(xy_list) != list:
             xy_list = [xy_list]
 
-        if pixel_center:
-            add_const = (float(pixel_size[0])/2.0, float(pixel_size[1])/2.0)
-        else:
-            add_const = (0.0, 0.0)
+        add_const = (float(pixel_size[0])/2.0) * pixel_center, \
+                    (float(pixel_size[1])/2.0) * pixel_center
 
         return list((float(xy[0]) * float(pixel_size[0]) + tie_point[0] + add_const[0],
                      float(xy[1]) * float(pixel_size[1]) + tie_point[1] + add_const[1])
@@ -1113,6 +1125,7 @@ class Raster(object):
                     time.sleep(random.random() + 1.0)
 
             if not read_success:
+                Opt.cprint('Retrying failed with {} attempts...using no-data value'.format(str(n_tries)))
                 tile_arr[jj, :, :] = self.nodatavalue
 
         if finite_only:
@@ -1200,7 +1213,7 @@ class Raster(object):
         id_geom_dict = dict()
         geom_types = []
 
-        for wkt_string_indx, wkt_string in enumerate(range(len(wkt_strings))):
+        for wkt_string_indx, wkt_string in enumerate(wkt_strings):
             # multi geometry should be separated
             if separate_multi_geom:
                 if ('MULTI' in wkt_string) or ('multi' in wkt_string):
@@ -1246,8 +1259,8 @@ class Raster(object):
         :param band_order: Order of bands to be extracted (list of band indices)  default: all bands
 
         :param kwargs: List of additional arguments
-                        tile_size : tuple (256, 256) default
-                                    Size of internal tiling
+                        tile_size : tuple (x size, y size)
+                                   Size of internal tiling
                         multi_geom_separate: bool (False) default
                                             if multi geometries should be separated or not
                         pass_pixel_coords: bool (False) default
@@ -1918,7 +1931,8 @@ class MultiRaster:
             lras.make_tile_grid(tile_size,
                                 tile_size)
 
-        Opt.cprint(lras)
+        if verbose:
+            Opt.cprint(lras)
 
         # make numpy array to hold the final result
         out_arr = np.zeros((lras.shape[1], lras.shape[2]),
@@ -1928,7 +1942,8 @@ class MultiRaster:
         count = 0
         for tie_pt, tile_arr in lras.get_next_tile(bands=t_order):
 
-            Opt.cprint(lras.tile_grid[count]['block_coords'])
+            if verbose:
+                Opt.cprint(lras.tile_grid[count]['block_coords'])
 
             _x, _y, _cols, _rows = lras.tile_grid[count]['block_coords']
 
@@ -1956,7 +1971,8 @@ class MultiRaster:
         if write_raster:
             # write raster
             lras.write_to_file(outfile)
-            Opt.cprint('Written {}'.format(outfile))
+            if verbose:
+                Opt.cprint('Written {}'.format(outfile))
         else:
             return lras
 
